==> vue-dialog-box-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/dialog-box/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import "@dftvue2-opentiny/vue-theme-mobile/dialog-box/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["update:visible", "change", "before-close", "open", "close", "opened", "confirm", "cancel", "closed"],
  props: [].concat(props, ["visible", "title", "modal", "closeOnClickModal", "modalAppendToBody", "appendToBody", "width", "top", "showHeader", "destroyOnClose"]),
  model: {
    prop: "visible",
    event: "update:visible"
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "dialog-fade"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    staticClass: "tiny-mobile-dialog-box__wrapper",
    on: {
      "click": function click($event) {
        if ($event.target !== $event.currentTarget)
          return null;
        return _vm.handleWrapperClick.apply(null, arguments);
      }
    }
  }, [_c("div", {
    key: _vm.state.key,
    ref: "dialog",
    staticClass: "tiny-mobile-dialog-box",
    class: {
      "is-hide-header": !_vm.showHeader
    }
  }, [_vm.showHeader ? _c("div", {
    staticClass: "tiny-mobile-dialog-box__header"
  }, [_vm._t("title", function() {
    return [_c("span", {
      staticClass: "tiny-mobile-dialog-box__title"
    }, [_vm._v(_vm._s(_vm.title))])];
  })], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-mobile-dialog-box__body"
  }, [_vm._t("default")], 2), _c("div", {
    staticClass: "tiny-mobile-dialog-box__footer"
  }, [_vm._t("footer", function() {
    return [_c("button", {
      staticClass: "tiny-mobile-dialog-box__button cancel-button",
      attrs: {
        "type": "button"
      },
      on: {
        "click": _vm.handleCancel
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.dialogBox.cancel")) + " ")]), _c("button", {
      staticClass: "tiny-mobile-dialog-box__button confirm-button",
      attrs: {
        "type": "button"
      },
      on: {
        "click": _vm.handleConfirm
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.dialogBox.confirm")) + " ")])];
  })], 2)])])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-dialog-box-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dialog-box/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme-mobile/dialog-box/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["update:visible", "change", "before-close", "open", "close", "opened", "confirm", "cancel", "closed"],
  props: [].concat(props, ["visible", "title", "modal", "closeOnClickModal", "modalAppendToBody", "appendToBody", "width", "top", "showHeader", "destroyOnClose"]),
  model: {
    prop: "visible",
    event: "update:visible"
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "dialog-fade"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    staticClass: "tiny-mobile-dialog-box__wrapper",
    on: {
      "click": function click($event) {
        if ($event.target !== $event.currentTarget) return null;
        return _vm.handleWrapperClick.apply(null, arguments);
      }
    }
  }, [_c("div", {
    key: _vm.state.key,
    ref: "dialog",
    staticClass: "tiny-mobile-dialog-box",
    class: {
      "is-hide-header": !_vm.showHeader
    }
  }, [_vm.showHeader ? _c("div", {
    staticClass: "tiny-mobile-dialog-box__header"
  }, [_vm._t("title", function() {
    return [_c("span", {
      staticClass: "tiny-mobile-dialog-box__title"
    }, [_vm._v(_vm._s(_vm.title))])];
  })], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-mobile-dialog-box__body"
  }, [_vm._t("default")], 2), _c("div", {
    staticClass: "tiny-mobile-dialog-box__footer"
  }, [_vm._t("footer", function() {
    return [_c("button", {
      staticClass: "tiny-mobile-dialog-box__button cancel-button",
      attrs: {
        "type": "button"
      },
      on: {
        "click": _vm.handleCancel
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.dialogBox.cancel")) + " ")]), _c("button", {
      staticClass: "tiny-mobile-dialog-box__button confirm-button",
      attrs: {
        "type": "button"
      },
      on: {
        "click": _vm.handleConfirm
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.dialogBox.confirm")) + " ")])];
  })], 2)])])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
